summaryrefslogtreecommitdiffstats
path: root/src/fetch/yahoofetcher.cpp
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-19 11:41:14 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-19 11:41:14 -0600
commit26f93a7d9105483b49ae930545ddb2873156fa8e (patch)
treebd208384438ff06193cc1a0a1548a9d69a83cd41 /src/fetch/yahoofetcher.cpp
parent8d9b90ca794ffabf151719c2edebe9278a2d3f36 (diff)
downloadtellico-26f93a7d9105483b49ae930545ddb2873156fa8e.tar.gz
tellico-26f93a7d9105483b49ae930545ddb2873156fa8e.zip
Remove additional unneeded tq method conversions
Diffstat (limited to 'src/fetch/yahoofetcher.cpp')
-rw-r--r--src/fetch/yahoofetcher.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/fetch/yahoofetcher.cpp b/src/fetch/yahoofetcher.cpp
index b54aae9..4637b26 100644
--- a/src/fetch/yahoofetcher.cpp
+++ b/src/fetch/yahoofetcher.cpp
@@ -91,7 +91,7 @@ void YahooFetcher::doSearch() {
u.addQueryItem(TQString::fromLatin1("results"), TQString::number(YAHOO_MAX_RETURNS_TOTAL));
if(!canFetch(Kernel::self()->collectionType())) {
- message(i18n("%1 does not allow searching for this collection type.").tqarg(source()), MessageHandler::Warning);
+ message(i18n("%1 does not allow searching for this collection type.").arg(source()), MessageHandler::Warning);
stop();
return;
}
@@ -237,7 +237,7 @@ Tellico::Data::EntryPtr YahooFetcher::fetchEntry(uint uid_) {
TQString id = ImageFactory::addImage(imageURL, true);
if(id.isEmpty()) {
// rich text causes tqlayout issues
// emit signalStatus(i18n("<qt>The cover image for <i>%1</i> could not be loaded.</qt>").tqarg(
// entry->field(TQString::fromLatin1("title"))));
message(i18n("The cover image could not be loaded."), MessageHandler::Warning);
} else {
@@ -237,7 +237,7 @@ Tellico::Data::EntryPtr YahooFetcher::fetchEntry(uint uid_) {
if(id.isEmpty()) {
// rich text causes tqlayout issues
-// emit signalStatus(i18n("<qt>The cover image for <i>%1</i> could not be loaded.</qt>").tqarg(
+// emit signalStatus(i18n("<qt>The cover image for <i>%1</i> could not be loaded.</qt>").arg(
// entry->field(TQString::fromLatin1("title"))));
message(i18n("The cover image could not be loaded."), MessageHandler::Warning);